package org.freecompany.yacli;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.RetentionPolicy.RUNTIME;
import static java.lang.annotation.ElementType.FIELD;

/**
 * The option annotation defines an option to be set on the target class
 * from the arguments provided on the command line. The command line
 * interface handles finding these options, validating them, and setting
 * any value(s) they may have on the {@link Runnable} main class before
 * executing it.
 */
@Retention( RUNTIME)
@Target( FIELD)
public @interface Option {

	String longName();
	String shortName();
	String description();
	Required required();
	Value value();
	String help() default "";
}	
